@@ -4,6 +4,7 @@ use crate::filename::disassemble;
 use crate::settings::Hyperlink;
 use lazy_static::lazy_static;
 use sanitize_filename_reader_friendly::sanitize;
+use std::borrow::Cow;
 use std::collections::HashMap;
 use std::hash::BuildHasher;
 use std::ops::Deref;
@@ -59,13 +60,11 @@ pub fn sanit_filter<S: BuildHasher>(
 
     // Take unmodified `String()`, but format all other types into
     // string.
-    let ps;
-    let pstr = if p.is_string() {
-        p.as_str().unwrap()
+    let mut p = if p.is_string() {
+        Cow::Borrowed(p.as_str().unwrap())
     } else {
         // Convert and format.
-        ps = p.to_string();
-        ps.as_str()
+        Cow::Owned(p.to_string())
     };
 
     let alpha_required = match args.get("alpha") {
@@ -73,9 +72,20 @@ pub fn sanit_filter<S: BuildHasher>(
         None => false,
     };
 
-    let mut filtered = sanitize(pstr);
-
     if alpha_required
+        && p.starts_with(&CFG.filename.sort_tag_chars.chars().collect::<Vec<char>>()[..])
+    {
+        p.to_mut().insert(0, CFG.filename.sort_tag_extra_separator);
+    };
+
+    let mut filtered = sanitize(&p);
+
+    // Normally `sort_tag_extra_separator` is chosen in way so that `sanitize()` will never
+    // `trim_start()` it. If ever it does, no problem, we add it a second time.
+    if alpha_required
+        // `sort_tag_extra_separator` is guaranteed not to be part of `sort_tag_chars`.
+        // Thus, the following makes sure, that we do not accidentally add two
+        // `sort_tag_extra_separator`.
         && filtered.starts_with(&CFG.filename.sort_tag_chars.chars().collect::<Vec<char>>()[..])
     {
         filtered.insert(0, CFG.filename.sort_tag_extra_separator);
@@ -396,6 +406,13 @@ mod tests {
         let result = sanit_filter(&to_value(123.4).unwrap(), &args);
         assert!(result.is_ok());
         assert_eq!(result.unwrap(), to_value(&"\'123.4").unwrap());
+
+        let mut args = HashMap::new();
+        args.insert("alpha".to_string(), to_value(true).unwrap());
+        // Note: the dot is trimmed by the `sanitize_filename_reader_friendly` lib.
+        let result = sanit_filter(&to_value(&".pdf").unwrap(), &args);
+        assert!(result.is_ok());
+        assert_eq!(result.unwrap(), to_value(&"'.pdf").unwrap());
     }
     #[test]
     fn test_linkname_linktarget_linktitle_filter() {
